DUNE-POLYGONGRID
================

[DUNE-POLYGONGRID][0] is a [Distributed and Unified Numerics Environment][1]
module which defines implements a polygonal grid for use with Virtual Element
(VEM), Finite Volume Methods (FV), and Discontinuous Galerkin Methods (DG).

Dependencies
------------

DUNE-POLYGONGRID depends on the following DUNE modules:

* [dune-common][3]

* [dune-geometry][4]

* [dune-grid][5]

License
-------

The DUNE-POLYGONGRID library, headers and test programs are free open-source software,
licensed under version 2 or later of the GNU General Public License.

See the file [LICENSE][6] for full copying permissions.

Installation
------------

For a full explanation of the DUNE installation process please read
the [installation notes][2].

 [0]: https://www.dune-project.org/modules/dune-polygongrid
 [1]: https://www.dune-project.org
 [2]: https://www.dune-project.org/doc/installation/
 [3]: http://gitlab.dune-project.org/core/dune-common
 [4]: http://gitlab.dune-project.org/core/dune-geometry
 [5]: http://gitlab.dune-project.org/core/dune-grid
 [6]: LICENSE.md


git-f286165743d56c1fbb980d49cb74c4f52ac25f94
